<?php

namespace Litecms\CustomService\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\CustomService\Models\CustomServices;

class CustomServicesPolicy
{

    /**
     * Determine if the given user can view the custom_services.
     *
     * @param UserPolicy $user
     * @param CustomServices $custom_services
     *
     * @return bool
     */
    public function view(UserPolicy $user, CustomServices $custom_services)
    {
        if ($user->canDo('custom_service.custom_services.view') && $user->isAdmin()) {
            return true;
        }

        return $custom_services->user_id == user_id() && $custom_services->user_type == user_type();
    }

    /**
     * Determine if the given user can create a custom_services.
     *
     * @param UserPolicy $user
     * @param CustomServices $custom_services
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('custom_service.custom_services.create');
    }

    /**
     * Determine if the given user can update the given custom_services.
     *
     * @param UserPolicy $user
     * @param CustomServices $custom_services
     *
     * @return bool
     */
    public function update(UserPolicy $user, CustomServices $custom_services)
    {
        if ($user->canDo('custom_service.custom_services.edit') && $user->isAdmin()) {
            return true;
        }

        return $custom_services->user_id == user_id() && $custom_services->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given custom_services.
     *
     * @param UserPolicy $user
     * @param CustomServices $custom_services
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, CustomServices $custom_services)
    {
        return $custom_services->user_id == user_id() && $custom_services->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given custom_services.
     *
     * @param UserPolicy $user
     * @param CustomServices $custom_services
     *
     * @return bool
     */
    public function verify(UserPolicy $user, CustomServices $custom_services)
    {
        if ($user->canDo('custom_service.custom_services.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given custom_services.
     *
     * @param UserPolicy $user
     * @param CustomServices $custom_services
     *
     * @return bool
     */
    public function approve(UserPolicy $user, CustomServices $custom_services)
    {
        if ($user->canDo('custom_service.custom_services.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
